@@ -284,6 +284,11 @@
 (define (get-value card)
       (car card))
 
+;; WARNING: This generates a synthetic card that isn't part of the game.
+;;          See gaps.scm for an example of its intended use.
+(define (add-to-value card n)
+  (cons (+ (car card) n) (cdr card)))
+
 ; slot procedures
 (define (get-cards slot-id)
   (cadr (get-slot slot-id)))
@@ -291,6 +296,13 @@
 (define (empty-slot? slot-id)
   (null? (get-cards slot-id)))
 
+; Get the nth card from a slot. Returns #f if n is out of range.
+(define (get-nth-card slot-id n)
+  (let ((cards (get-cards slot-id)))
+    (cond ((< n 1) #f)
+	  ((> n (length cards)) #f)
+	  (#t (list-ref cards (- n 1))))))
+
 (define (get-top-card slot-id)
   (let ((cards (get-cards slot-id)))
     (if (null? cards)
@@ -613,7 +625,7 @@
   (lambda (names)
     (if (equal? '() names)
         '()
-        (cons (eval-1 (car names)) 
+        (cons (eval-1 (list 'copy-tree (car names))) 
               (save-variables (cdr names))))))
 
 ; Restore all the state variables for a game
@@ -621,7 +633,7 @@
   (lambda (names values)
     (or (equal? '() names)
         (begin
-          (eval-1 (list 'set! (car names) (car values)))
+          (eval-1 (list 'set! (car names) (list 'quote (car values))))
           (restore-variables (cdr names) (cdr values))
           ))))
 
